==> artemis_cupps-0.0.41.tar.gz: lib/classes/Devices/be_device.dart <==
import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../classes.dart';

class BeDevice extends Device {
  BeDevice(
      {required BeDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory BeDevice.fromDevice(Device d) {
    return BeDevice(
      deviceParameter: BeDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
}

class BeDeviceParameter extends DeviceParameter {
  final String duration;
  final String pitch;
  final String volume;

  BeDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.duration,
    required this.pitch,
    required this.volume,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory BeDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("beStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    BeStatus status = BeStatus.fromXML(statusElement!.toXmlString());

    String duration = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "duration")
        .value;
    String volume = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "volume")
        .value;
    String pitch = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "pitch")
        .value;
    return BeDeviceParameter(
        vendorModelInfo: vendorModelInfo,
        ipAndPort: ipAndPort,
        status: status,
        duration: duration,
        pitch: pitch,
        volume: volume);
  }

  @override
  String toXML() {
    return '''<beDeviceParameter duration="$duration" pitch="$pitch" volume="$volume" >
    ${vendorModelInfo.toXML()}
    ${ipAndPort.toXML()}
    ${status.toXML()}
    </beDeviceParameter>
    ''';
  }
}

class BeStatus extends Status {
  BeStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory BeStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    return BeStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown);
  }

  @override
  String toXML() {
    return '''<beStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown"/>''';
  }

  String? get icon {
    return null;
  }
}

==> artemis_cupps-0.0.62.tar.gz: lib/classes/Devices/be_device.dart <==
import '../../artemis_cupps.dart';
import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../classes.dart';

class BeDevice extends Device {
  BeDevice(
      {required BeDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes,
            socketService: SocketService(ip: deviceParameter.ipAndPort.ip, port: int.tryParse(deviceParameter.ipAndPort.port)??0)

  );

  factory BeDevice.fromDevice(Device d) {
    return BeDevice(
      deviceParameter: BeDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
}

class BeDeviceParameter extends DeviceParameter {
  final String duration;
  final String pitch;
  final String volume;

  BeDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.duration,
    required this.pitch,
    required this.volume,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory BeDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("beStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    BeStatus status = BeStatus.fromXML(statusElement!.toXmlString());

    String duration = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "duration")
        .value;
    String volume = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "volume")
        .value;
    String pitch = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "pitch")
        .value;
    return BeDeviceParameter(
        vendorModelInfo: vendorModelInfo,
        ipAndPort: ipAndPort,
        status: status,
        duration: duration,
        pitch: pitch,
        volume: volume);
  }

  @override
  String toXML() {
    return '''<beDeviceParameter duration="$duration" pitch="$pitch" volume="$volume" >
    ${vendorModelInfo.toXML()}
    ${ipAndPort.toXML()}
    ${status.toXML()}
    </beDeviceParameter>
    ''';
  }
}

class BeStatus extends Status {
  BeStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory BeStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    return BeStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown);
  }

  @override
  String toXML() {
    return '''<beStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown"/>''';
  }

  String? get icon {
    return null;
  }
}
